@@ -250,7 +250,7 @@ class CodeBoxesHandler:
             anchor.sourcebuffer.place_cursor(anchor.sourcebuffer.get_iter_at_offset(cursor_pos))
             anchor.sourcebuffer.set_modified(False)
         anchor.sourceview = gtksourceview2.View(anchor.sourcebuffer)
-        anchor.sourceview.set_smart_home_end(gtksourceview2.SMART_HOME_END_BEFORE)
+        anchor.sourceview.set_smart_home_end(gtksourceview2.SMART_HOME_END_AFTER)
         if self.dad.highl_curr_line: anchor.sourceview.set_highlight_current_line(True)
         if self.dad.show_white_spaces: anchor.sourceview.set_draw_spaces(DRAW_SPACES_FLAGS)
         if anchor.syntax_highlighting == cons.PLAIN_TEXT_ID:
