@@ -33,7 +33,7 @@ COLOR_PALETTE_DEFAULT = ["#000000", "#ffffff", "#7f7f7f", "#ff0000", "#a020f0",
                          "#0000ff", "#add8e6", "#00ff00", "#ffff00", "#ffa500",
                          "#e6e6fa", "#a52a2a", "#8b6914", "#1e90ff", "#ffc0cb",
                          "#90ee90", "#1a1a1a", "#4d4d4d", "#bfbfbf", "#e5e5e5"]
-SPECIAL_CHARS_DEFAULT = "“”„•☐☑☒…‰€©®™°↓↑→←↔↵⇓⇑⇒⇐⇔»«▼▲►◄≤≥≠±¹²³½¼⅛×÷∞ø∑√∫ΔδΠπΣΦΩωαβγεηλμ☺☻☼♥♀♂♪♫"
+SPECIAL_CHARS_DEFAULT = "“”„•◇▪▸☐☑☒…‰€©®™°↓↑→←↔↵⇓⇑⇒⇐⇔»«▼▲►◄≤≥≠±¹²³½¼⅛×÷∞ø∑√∫ΔδΠπΣΦΩωαβγεηλμ☺☻☼♥♀♂♪♫"
 SELWORD_CHARS_DEFAULT = ".-@"
 TOOLBAR_VEC_DEFAULT = ["TreeAddNode", "TreeAddSubNode", cons.TAG_SEPARATOR, "GoBack", "GoForward", cons.TAG_SEPARATOR, cons.CHAR_STAR, "Save", "Export2PDF", cons.TAG_SEPARATOR, "FindInNodes", cons.TAG_SEPARATOR, "BulletedList", "NumberedList", "ToDoList", cons.TAG_SEPARATOR, "HandleImage", "HandleTable", "HandleCodeBox", "EmbFileInsert", "HandleLink", "HandleAnchor", cons.TAG_SEPARATOR, "RemoveFormatting", "ColorForeground", "ColorBackground", "Bold", "Italic", "Underline", "Strikethrough", "H1", "H2", "H3", "Small", "Superscript", "Subscript", "Monospace"]
 TOOLBAR_VEC_BLACKLIST = ["CutAnchor", "CopyAnchor", "DeleteAnchor", "EditAnchor", "CutEmbFile", "CopyEmbFile", "DeleteEmbFile", "EmbFileSave", "EmbFileOpen", "SaveImage", "EditImage", "CutImage", "CopyImage", "DeleteImage", "EditImageLink", "DismissImageLink", "ShowHideMainWin"]
@@ -347,7 +347,7 @@ def config_file_save(inst):
     config.add_section(section)
     config.set(section, "file_dir", inst.file_dir)
     config.set(section, "file_name", inst.file_name)
-    config.set(section, "toolbar_visible", inst.ui.get_widget("/ToolBar").get_property(cons.STR_VISIBLE))
+    config.set(section, "toolbar_visible", inst.toolbar_visible)
     config.set(section, "win_is_maximized", inst.win_is_maximized)
     inst.win_position = inst.window.get_position()
     config.set(section, "win_position_x", inst.win_position[0])
@@ -370,7 +370,7 @@ def config_file_save(inst):
     config.set(section, "recent_docs", str_recent_docs)
     config.set(section, "pick_dir", inst.pick_dir)
     config.set(section, "link_type", inst.link_type)
-    config.set(section, "show_node_name_label", inst.header_node_name_label.get_property(cons.STR_VISIBLE))
+    config.set(section, "show_node_name_label", inst.show_node_name_label)
     config.set(section, "toolbar_icon_size", inst.toolbar_icon_size)
     if inst.curr_colors['f']: config.set(section, "fg", inst.curr_colors['f'].to_string())
     if inst.curr_colors['b']: config.set(section, "bg", inst.curr_colors['b'].to_string())
