@@ -22,7 +22,7 @@
 import os, sys
 
 
-VERSION = "0.35.8"
+VERSION = "0.35.10"
 APP_NAME = "cherrytree"
 NEWER_VERSION_URL = "http://www.giuspen.com/software/version_cherrytree"
 if sys.platform.startswith("win"):
@@ -63,7 +63,7 @@ except: HAS_APPINDICATOR = False
 XDG_CURRENT_DESKTOP = 'XDG_CURRENT_DESKTOP'
 HAS_SYSTRAY = not (XDG_CURRENT_DESKTOP in os.environ and os.environ[XDG_CURRENT_DESKTOP] == "Unity")
 
-AVAILABLE_LANGS = ['default', 'cs', 'de', 'en', 'es', 'fr', 'hy', 'it', 'nl', 'pl', 'pt_BR', 'ru', 'uk', 'zh_CN']
+AVAILABLE_LANGS = ['default', 'cs', 'de', 'en', 'es', 'fr', 'hy', 'it', 'ja', 'nl', 'pl', 'pt_BR', 'ru', 'tr', 'uk', 'zh_CN']
 COLOR_48_LINK_WEBS = "#00004444ffff"
 COLOR_48_LINK_NODE = "#071c838e071c"
 COLOR_48_LINK_FILE = "#8b8b69691414"
@@ -145,7 +145,9 @@ CHAR_NEWPAGE = "\x0c"
 CHAR_CR = "\r"
 CHAR_TAB = "\t"
 CHAR_LISTBUL = "•"
-CHAR_LISTARR = "►"
+CHAR_LISTARR = "▸"
+CHAR_LISTBUL2 = "◇"
+CHAR_LISTBUL3 = "▪"
 CHAR_LISTTODO = "☐"
 CHAR_LISTDONEOK= "☑"
 CHAR_LISTDONEFAIL= "☒"
@@ -191,6 +193,7 @@ STR_IGNORE = "ignore"
 STR_KEY_RETURN = "Return"
 STR_KEY_DELETE = "Delete"
 STR_KEY_TAB = "Tab"
+STR_KEY_SPACE = "space"
 STR_KEY_MENU = "Menu"
 STR_KEY_UP = "Up"
 STR_KEY_DOWN = "Down"
@@ -198,7 +201,14 @@ STR_KEY_LEFT = "Left"
 STR_KEY_RIGHT = "Right"
 STR_PYGTK_222_REQUIRED = "PyGTK 2.22 required"
 
-HTML_HEADER = '<!doctype html><html><head><meta http-equiv="content-type" content="text/html; charset=utf-8"><title>%s</title><meta name="generator" content="CherryTree"></head><body>'
+HTML_HEADER = '''<!doctype html><html>
+<head>
+  <meta http-equiv="content-type" content="text/html; charset=utf-8">
+  <title>%s</title>
+  <meta name="generator" content="CherryTree">
+  <link rel="stylesheet" href="styles.css" type="text/css" />
+</head>
+<body>'''
 HTML_FOOTER = '</body></html>'
 
 STOCKS_N_FILES = [
