@@ -53,12 +53,20 @@ class CherryTreeHandler():
         self.running_windows = []
         self.embfiles_id = 0
         self.systray_active = False
-        self.window_open_new(filepath_fix(args.filepath), args.node, True, True if args.filepath else False)
-        self.server_check_timer_id = gobject.timeout_add(1000, self.server_periodic_check) # 1 sec
+
+        if args.export_to_html_dir:
+            if args.filepath:
+                ghost_window = core.CherryTree(self.lang_str, filepath_fix(args.filepath), args.node, self, True, True, True)
+                ghost_window.export_to_html("Auto", args.export_to_html_dir)
+            else:
+                print "Export error: input not specified"
+        else:
+            self.window_open_new(filepath_fix(args.filepath), args.node, True, True if args.filepath else False)
+            self.server_check_timer_id = gobject.timeout_add(1000, self.server_periodic_check) # 1 sec
 
     def window_open_new(self, filepath, node_name, is_startup, is_arg):
         """Open a new top level Window"""
-        window = core.CherryTree(self.lang_str, filepath, node_name, self, is_startup, is_arg)
+        window = core.CherryTree(self.lang_str, filepath, node_name, self, is_startup, is_arg, False)
         self.running_windows.append(window)
         #print self.running_windows
 
@@ -110,11 +118,11 @@ class CherryTreeHandler():
                 else:
                     # 3) check for opened window hidden (systray) in case there's no filepath (run from launcher)
                     just_run_new_win = True
-                    if not msg_server_to_core['p']:
+                    if not msg_server_to_core['p'] or msg_server_to_core['p'].endswith("None"):
                         for i, runn_win in enumerate(self.running_windows):
                             if not runn_win.window.get_property(cons.STR_VISIBLE):
                                 print "3 rise existing hidden in systray"
-                                runn_win.window.present()
+                                runn_win.toggle_show_hide_main_window()
                                 just_run_new_win = False
                                 break
                     if just_run_new_win:
@@ -191,7 +199,11 @@ def main(args):
         DBUS_OK = True
     except:
         DBUS_OK = False
-    if DBUS_OK:
+
+    if args.export_to_html_dir:
+        lang_str = initializations()
+        CherryTreeHandler(args, lang_str)
+    elif DBUS_OK:
         try:
             # client
             remote_object = session_bus.get_object("com.giuspen.CherryTreeService", "/CherryTreeObject")
